#
# spec file for package conntrack-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if !%{defined _fillupdir}
# Leap/TW 15+
%define _fillupdir /var/adm/fillup-templates
%endif

Name:           conntrack-tools
VCS: https://src.suse.de/ALP-pool/conntrack-tools#d6587e05808bbdd4561eceaa8ff24ccede9425d5
Version:        1.4.8
Release:        1.6
Summary:        Userspace tools for interacting with the Connection Tracking System
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://conntrack-tools.netfilter.org/

#Git-Clone:	git://git.netfilter.org/conntrack-tools
Source:         https://www.netfilter.org/projects/conntrack-tools/files/conntrack-tools-%version.tar.xz
Source2:        https://www.netfilter.org/projects/conntrack-tools/files/conntrack-tools-%version.tar.xz.sig
Source3:        %name.keyring
Source5:        conntrackd.service
Source6:        conntrackd.README.SUSE
Source7:        conntrackd.logrotate
Source8:        conntrackd.sysconfig
Source9:        conntrackd.conf

BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex >= 2.5.33
BuildRequires:  libtool
BuildRequires:  pkg-config >= 0.21
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  pkgconfig(libmnl) >= 1.0.3
BuildRequires:  pkgconfig(libnetfilter_conntrack) >= 1.0.9
BuildRequires:  pkgconfig(libnetfilter_cthelper) >= 1.0.0
BuildRequires:  pkgconfig(libnetfilter_cttimeout) >= 1.0.0
BuildRequires:  pkgconfig(libnetfilter_queue) >= 1.0.2
BuildRequires:  pkgconfig(libnfnetlink) >= 1.0.1
BuildRequires:  pkgconfig(libsystemd) >= 227
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(libtirpc)
%endif

%description
The conntrack/nfct utilities provide the userspace interface to the
Netfilter connection tracking, replacing
/proc/net/ip_conntrack. The tools can be used to search, list,
inspect and maintain the connection tracking subsystem of the Linux
kernel.

%package -n conntrackd
Summary:        Connection tracking daemon
Group:          Productivity/Networking/Security
Provides:       conntrack-tools:/usr/sbin/conntrackd
Requires:       conntrack-tools = %version-%release
Requires(post): fillup
Recommends:     logrotate

%description -n conntrackd
conntrackd is the user-space daemon for the Netfilter connection tracking
system. This daemon synchronizes connection tracking states between several
replica firewalls.

%prep
%setup -q
find doc -type f -name "*.orig" -delete
find doc -type f -exec chmod -x "{}" "+"

%build
autoreconf -vif
%configure --disable-static --enable-systemd
# CC       read_config_lex.o
#read_config_lex.l:24:28: fatal error: read_config_yy.h: No such file or
#directory
%make_build -j1

%install
%make_install
b="%buildroot"
ln -s service "$b/%_sbindir/rcconntrackd"
find "$b/%_libdir" -type f -name "*.la" -delete
install -Dpm0644 "%_sourcedir"/conntrackd.service "$b/%_unitdir/conntrackd.service"
install -Dpm0644 "%_sourcedir/conntrackd.sysconfig" "$b/%_fillupdir/sysconfig.conntrackd"
install -Dpm0644 "%_sourcedir/conntrackd.logrotate" "$b/%_sysconfdir/logrotate.d/conntrackd"
b="%buildroot/%_docdir/%name"
mkdir -p "$b"
cp -a "%_sourcedir/conntrackd.README.SUSE" "%_sourcedir/conntrackd.conf" "$b/"

%pre -n conntrackd
%service_add_pre conntrackd.service

%post -n conntrackd
%fillup_only -n conntrackd
if [ "$1" -eq 1 -a ! -e "%_sysconfdir/conntrackd/conntrackd.conf" ]; then
	install -Dpm0644 "%_docdir/%name/conntrackd.conf" "%_sysconfdir/conntrackd/conntrackd.conf"
fi
%service_add_post conntrackd.service

%preun -n conntrackd
%service_del_preun conntrackd.service

%postun -n conntrackd
%service_del_postun conntrackd.service

%files
%_sbindir/conntrack
%_sbindir/nfct
%_mandir/man8/conntrack.8*
%_mandir/man8/nfct.8*
# Shared betweenn nfct and conntrackd:
%_libdir/%name/

%files -n conntrackd
%_sysconfdir/logrotate.d/conntrackd*
%_sbindir/conntrackd
%_sbindir/rcconntrackd
%_mandir/man5/conntrackd*
%_mandir/man8/conntrackd*
%dir %_docdir/%name
%_docdir/%name/conntrackd*
%_unitdir/conntrackd*
%_fillupdir/*conntrackd

%changelog
* Fri Sep 29 2023 jengelh@inai.de
- Update to release 1.4.8
  * Fix spurious EOPNOSUPP and ENOBUFS errors with -U/--update
    command.
  * Fix spurious ENOENT -D/--delete.
* Thu Oct  6 2022 jengelh@inai.de
- Update to release 1.4.7
  * Changes to the "conntrack" program:
  * "clash_resolve" and "chaintoolong" stats counters
  * Defaults to the `unspec` family if the `-f` flag is absent,
    so as to improve support for dual-stack setups.
  * Support filtering events by IP address family.
  * Support flushing per IP address family.
  * Added the `save` output format representing data in conntrack
    parameters, and support for loading such files back.
  * Remove the `-o userspace` flag and always tag user space
    triggered events.
  * Introduce the `-A` flags, a variant of `-I` which does not
    fail if the entry exists already.
* Mon Aug 30 2021 jsegitz@suse.com
- Added hardening to systemd service(s). Modified:
  * conntrackd.service
* Wed Apr  1 2020 jengelh@inai.de
- Update to release 1.4.6
  * conntrackd: fix UDP IPv6 destination address not being usable
  * conntrack: Allow protocol number zero
  * conntrackd: cthelper: Add new SLP helper
- Drop conntrackd-Use-strdup-in-lexer.patch,
  conntrackd-use-strncpy-to-unix-path.patch,
  conntrackd-cthelper-Add-new-SLP-helper.patch,
  conntrackd-use-correct-max-unix-path-length.patch (merged)
- Drop require on systemd, since it can run in a namespace without.
* Tue Jul 23 2019 mkubecek@suse.cz
- conntrackd-cthelper-Add-new-SLP-helper.patch:
  userspace conntrack helper for SLP (Service Location Protocol) to
  replace SUSE specific kernel helper (rejected by upstream) from
  openSUSE / SLE kernel packages (FATE#324143 bsc#1127886)
- run autoreconf before build (patch above touches Makefile.am)
- add commented out conntrack helper config example to default
  conntrackd.conf
- drop deprecated (and ignored) options Nice and UNIX/Backlog from
  default conntrackd.conf
* Mon Jul 15 2019 mkubecek@suse.cz
- Fix 1.4.5 parser issues (bsc#1141480):
  conntrackd-use-strncpy-to-unix-path.patch
  conntrackd-Use-strdup-in-lexer.patch
  conntrackd-use-correct-max-unix-path-length.patch
* Tue May  1 2018 jengelh@inai.de
- Update to new upstream release 1.4.5
  * new synproxy support
  * improved logging support (both stdout/stderr and log files)
  * new mDNS ct helper
  * deprecate unix backlog configuration
  * drop old/obsolete/deprecated conntrackd.conf config options
  * improved support for UPnP in the SSDP ct helper
  * add stronger TCP flags support
  * conntrack CLI tool: new support for IPv6 NAT
  * nfct CLI tool: some improvements to the build (-z lazy)
* Fri Mar 16 2018 jengelh@inai.de
- Add tirpc for openSUSE 15 and onwards.
* Tue Jan 16 2018 jengelh@inai.de
- submission from lars@linux-schulserver.de, partially applied
- split out new subpackage "conntrackd" for the eponymous
  daemon (has systemd dependencies)
- add systemd service, logrotate config, sample sysconfig,
  and sample config file.
* Mon Aug 22 2016 jengelh@inai.de
- Update to new upstream release 1.4.4
  * conntrackd: add systemd support
  * conntrack: support delete by label
  * conntrack: add support for netmask filtering
  * conntrack: add support for CIDR notation
  * conntrack: Add missing tables "dying" and "unconfirmed"
  to usage output.
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 1.4.3
  * conntrack: fix expectation entry creation
  * expect: Fix wrong memset usage
  * cthelper: don't pass up a 0 length queue
  * conntrackd: allow strings with underscore from flex scanner
  * conntrack: fix setting labels in updates
* Thu Jan  8 2015 jengelh@inai.de
- Update to new git snapshot 1.4.2.g26
  * Chromecast/SSDP support, SSDP userspace helper
  * TFTP userspace helper support
  * Support for attaching expectations via nfqueue
  * Fix directory lookup for helper plugins
  * Fixes a possible crash if conntrackd sees DCCP, SCTP and ICMPv6
  traffic and the corresponding kernel modules that track this
  traffic are not available. [bnc#942419, CVE-2015-6496]
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 1.4.2
  * This release includes bugfixes and the connlabel support.
* Mon Mar  4 2013 jengelh@inai.de
- Update to new upstream release 1.4.1
  * conntrack: add support to dump the dying and unconfirmed list via
  ctnetlink
  * conntrackd: fix deadlock due to wrong nested signal blocking
* Tue Nov 20 2012 sbrabec@suse.cz
- Verify GPG signature
* Mon Oct  8 2012 jengelh@inai.de
- Update to new upstream release 1.4.0
  * This release adds the user-space helper infrastructure which
  includes the RPC portmapper (to support NFSv3) and Oracle*TNS
  helpers.
* Tue Jul 31 2012 jengelh@inai.de
- Update to new upstream release 1.2.2
  * conntrackd: commit operation has to be synchronous
  * conntrackd: implement selective flushing for -t and -F commands
* Thu May 31 2012 jengelh@inai.de
- Resolve compilation failure due to missing #include
* Sat May 26 2012 jengelh@inai.de
- Update to new upstream release 1.2.1
  * Add support for NAT expectations, synchronization of expectation
  class, helper names and expect functions. Filtering by mark is
  now allowed.
* Wed Jan  4 2012 jengelh@medozas.de
- Update to new upstream release 1.0.1
  * add support for mark masks
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sun Feb 27 2011 jengelh@medozas.de
- new upstream release 1.0.0
  * SYN_SENT2 support for the command line tool conntrack (which was
  added in Linux kernel >= 2.6.31).
  * allow to listen to update and destroy expectation events (it
  requires a Linux kernel >= 2.6.37).
  * conntrack timestamping support with -o ktimestamp (this support
  requires the upcoming Linux 2.6.38).
  * one fix for conntrackd: two very consecutive commit invocations
  with option -c may result in the hang of the second commit
  invocation if the first commit did not finish yet. As a result the
  second commit invocation required a manual SIGTERM.
- Remove redundant %%clean section
* Thu Jul 15 2010 jengelh@medozas.de
- new upstream release 0.9.15
  * support for conntrack zones
  * support for TCP window scale synchronization
  * fixes to option parsing and printouts
* Tue Feb 23 2010 jengelh@medozas.de
- new upstream release: 0.9.14
- use %%_smp_mflags
- wrap description at col 70
* Sun Sep 20 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.9.13
